/***************************************************************************
 *   Copyright (C) 2008 by Montel Laurent <montel@kde.org>                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
 ***************************************************************************/

#ifndef AUTOSTARTITEM_H
#define AUTOSTARTITEM_H

#include <QTreeWidget>
#include <QTreeWidgetItem>
#include <QObject>
#include <KUrl>

class AutoStartItem : public QTreeWidgetItem, public QObject
{
public:
    AutoStartItem(const QString &service, QTreeWidgetItem *parent);
    ~AutoStartItem();

    KUrl fileName() const;

    void setPath(const QString &path);

private:
    KUrl m_fileName;
};

#endif // AUTOSTARTITEM_H
